Public Class FormMain

#Region " User interface related events  "

    Private Sub LinkLabelConfigureSensor_LinkClicked(ByVal sender As System.Object, ByVal e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles LinkLabelConfigureSensor.LinkClicked
        Me.TimerSensor.Enabled = False
        Dim F As New FormSensorOptions
        If F.ShowDialog(Me) = Windows.Forms.DialogResult.OK Then
            Me.RefreshSensor()
        Else
            Me.TimerSensor.Enabled = True
        End If
    End Sub

    Private Sub LinkLabelConfigureService_LinkClicked(ByVal sender As System.Object, ByVal e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles LinkLabelConfigureService.LinkClicked
        Me.TimerService.Enabled = False
        Dim F As New FormServiceOptions
        If F.ShowDialog(Me) = Windows.Forms.DialogResult.OK Then
            Me.RefreshService()
        Else
            Me.TimerService.Enabled = True
        End If
    End Sub

    Private Sub LinkLabelRefreshSensor_LinkClicked(ByVal sender As System.Object, ByVal e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles LinkLabelRefreshSensor.LinkClicked
        Me.RefreshSensor()
    End Sub

    Private Sub LinkLabelRefreshService_LinkClicked(ByVal sender As System.Object, ByVal e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles LinkLabelRefreshService.LinkClicked
        Me.RefreshService()
    End Sub

    Private Sub TimerService_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles TimerService.Tick
        Me.RefreshService()
    End Sub

    Private Sub TimerSensor_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles TimerSensor.Tick
        Me.RefreshSensor()
    End Sub



#End Region

#Region " NotifyIcon related events "
    Private Sub FormMain_Resize(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Resize
        If Me.WindowState = FormWindowState.Minimized Then
            Me.Visible = False
            Me.TrayIcon.Visible = True
        End If
    End Sub

    Private Sub TrayIcon_MouseClick(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles TrayIcon.MouseClick
        If e.Button = Windows.Forms.MouseButtons.Right Then
            Me.Visible = True
            Me.TrayIcon.Visible = False
            Me.WindowState = FormWindowState.Normal
        Else
            Dim Message As String = String.Format("{0}: {1}\n{2}: {3}", Me.GroupBoxSensor.Text, Me.LabelSensor.Text, Me.GroupBoxService.Text, Me.LabelService.Text)
            Me.TrayIcon.ShowBalloonTip(5, "Current temperature", Message.Replace("\n", vbCrLf), ToolTipIcon.Info)
        End If
    End Sub
#End Region

    Private Sub RefreshSensor()
        ' Disable all related controls
        Me.TimerSensor.Enabled = False
        Me.LinkLabelConfigureSensor.Enabled = False
        Me.LinkLabelRefreshSensor.Enabled = False

        Try
            ' Connect to serial port
            Dim Port As New System.IO.Ports.SerialPort()
            Port.PortName = My.Settings.SensorPortName
            Port.BaudRate = My.Settings.SensorBaudRate
            Port.DataBits = My.Settings.SensorDataBits
            Port.StopBits = My.Settings.SensorStopBits
            Port.Parity = My.Settings.SensorParity
            Port.ReadTimeout = My.Settings.SensorTimeout
            Port.DtrEnable = True
            Port.Open()

            ' Read data
            Dim S As String = Port.ReadTo("C")
            Dim T As Double = Double.Parse(S.Substring(0, 6), New System.Globalization.CultureInfo("en-US"))
            Port.Close()
            Port.Dispose()

            ' Display results
            Me.LabelSensor.Text = String.Format("{0:N1}C", T)
            Me.LabelUpdateSensor.Text = DateTime.Now.ToShortDateString() & " " & DateTime.Now.ToShortTimeString()
        Catch tex As TimeoutException
            ' Nothing - ignore timeout
        End Try

        ' Set update interval
        Me.TimerSensor.Interval = My.Settings.SensorUpdateInterval

        ' Enable all related controls
        Me.TimerSensor.Enabled = True
        Me.LinkLabelConfigureSensor.Enabled = True
        Me.LinkLabelRefreshSensor.Enabled = True
    End Sub

    Private Sub RefreshService()
        ' Disable all related controls
        Me.TimerService.Enabled = False
        Me.LinkLabelConfigureService.Enabled = False
        Me.LinkLabelRefreshService.Enabled = False

        ' Create instance of web service
        Dim WeatherWS As New GlobalWeather.GlobalWeather()
        Dim Report As GlobalWeather.WeatherReport = WeatherWS.getWeatherReport(My.Settings.ServiceLocationCode)
        If Not Report Is Nothing Then
            ' Display results
            Me.LabelService.Text = String.Format("{0:N1}C", Report.temperature.ambient)
            Me.GroupBoxService.Text = String.Format("{0} ({1})", Report.station.name, Report.station.country)
            Me.LabelUpdateService.Text = Report.timestamp.Value.ToShortDateString() & " " & Report.timestamp.Value.ToShortTimeString()
        End If
        WeatherWS.Dispose()

        ' Set update interval
        Me.TimerService.Interval = My.Settings.ServiceUpdateInterval

        ' Enable all related controls
        Me.TimerService.Enabled = True
        Me.LinkLabelConfigureService.Enabled = True
        Me.LinkLabelRefreshService.Enabled = True
    End Sub

End Class
